.. _{{ fullname }}:

.. raw:: html

    <br>

.. title:: {{ fullname }}

.. raw:: html

    <center>
    <h3>

{{ fullname }}

.. raw:: html

    </h3>
    </center>

.. auto{{ objtype }}:: {{ fullname }}
    :members:
    :private-members:
    :undoc-members:

.. raw:: html

    <br><br>
